@@ -12,7 +12,7 @@ from rich.logging import RichHandler
 
 from griffon.output import console
 
-__version__ = "0.1.21"
+__version__ = "0.2.16"
 
 if "CORGI_API_URL" not in os.environ:
     print("Must set CORGI_API_URL environment variable.")
@@ -32,6 +32,9 @@ COMMUNITY_COMPONENTS_API_URL = os.getenv(
     "COMMUNITY_COMPONENTS_API_URL", "https://component-registry.fedoraproject.org"
 )
 
+# TODO: temporary hack required to enable searching of middleware
+MIDDLEWARE_CLI = os.getenv("GRIFFON_MIDDLEWARE_CLI")
+
 GRIFFON_CONFIG_DIR = os.getenv("GRIFFON_API_URL", "~/.griffon")
 GRIFFON_RC_FILE = "~/.griffonrc"
 GRIFFON_DEFAULT_LOG_FILE = os.getenv("GRIFFON_DEFAULT_LOG_FILE", "~/.griffon/history.log")
@@ -175,7 +178,7 @@ class OSIDBService:
         # is changed and released we can change it back to normal
         #
         # return osidb_bindings.bindings.python_client.models.FlawResolutionEnum
-        return osidb_bindings.bindings.python_client.models.Resolution01FEnum
+        return osidb_bindings.bindings.python_client.models.ResolutionEnum
 
     @staticmethod
     def get_flaw_impacts():
@@ -197,7 +200,7 @@ class OSIDBService:
         # is changed and released we can change it back to normal
         #
         # return osidb_bindings.bindings.python_client.models.AffectResolutionEnum
-        return osidb_bindings.bindings.python_client.models.Resolution3AcEnum
+        return osidb_bindings.bindings.python_client.models.ResolutionEnum
 
     @staticmethod
     def get_affect_impact():
