@@ -3,12 +3,20 @@
 """
 import copy
 import logging
+import subprocess
+from json import loads
 
 import click
 from component_registry_bindings.bindings.python_client.api.v1 import v1_components_list
 from component_registry_bindings.bindings.python_client.models import Component
 
-from griffon import CorgiService, OSIDBService, progress_bar
+from griffon import (
+    MIDDLEWARE_CLI,
+    CorgiService,
+    OSIDBService,
+    get_config_option,
+    progress_bar,
+)
 from griffon.autocomplete import (
     get_component_names,
     get_cve_ids,
@@ -28,7 +36,14 @@ from griffon.commands.reports import (
     generate_entity_report,
     generate_license_report,
 )
-from griffon.output import console, cprint, raw_json_transform
+from griffon.output import (
+    console,
+    cprint,
+    generate_affects,
+    generate_normalised_results,
+    generate_result_tree,
+    raw_json_transform,
+)
 from griffon.services import QueryService, core_queries  # , exp
 
 logger = logging.getLogger("griffon")
@@ -82,10 +97,19 @@ queries_grp.add_command(generate_license_report)
     default=False,
     help="Return all Products.",
 )
+@click.option(
+    "-v",
+    "verbose",
+    count=True,
+    default=get_config_option("default", "verbosity", 0),
+    help="Verbose output, more detailed search results, can be used multiple times (e.g. -vvv).",
+)  # noqa
 @click.pass_context
 @progress_bar
-def get_product_summary(ctx, product_stream_name, strict_name_search, all):
+def get_product_summary(ctx, product_stream_name, strict_name_search, all, verbose):
     """get product stream."""
+    if verbose:
+        ctx.obj["VERBOSE"] = verbose
     if not product_stream_name and not all and not strict_name_search:
         click.echo(ctx.get_help())
         exit(0)
@@ -199,7 +223,21 @@ def retrieve_component_summary(ctx, component_name, strict_name_search):
     "search_all",
     is_flag=True,
     default=False,
-    help="Search root Components and dependencies.",
+    help="Search all Components and dependencies.",
+)
+@click.option(
+    "--search-all-roots",
+    "search_all_roots",
+    is_flag=True,
+    default=False,
+    help="Search all ROOT Components and dependencies.",
+)
+@click.option(
+    "--search-redhat",
+    "search_redhat",
+    is_flag=True,
+    default=False,
+    help="Search all Red Hat root Components and dependencies.",
 )
 @click.option(
     "--search-community",
@@ -215,6 +253,48 @@ def retrieve_component_summary(ctx, component_name, strict_name_search):
     default=False,
     help="Search for Components by upstream.",
 )
+@click.option(
+    "--no-community",
+    "no_community",
+    is_flag=True,
+    default=False,
+    help="Do not search community.",
+)
+@click.option(
+    "--no-middleware",
+    "no_middleware",
+    is_flag=True,
+    default=False,
+    help="Do not search middleware.",
+)
+@click.option(
+    "--include-inactive-product-streams",
+    "include_inactive_product_streams",
+    is_flag=True,
+    default=get_config_option("default", "include_inactive_product_streams", False),
+    help="Include components from inactive product streams.",
+)
+@click.option(
+    "--include-product-streams-excluded-components",
+    "include_product_stream_excluded_components",
+    is_flag=True,
+    default=get_config_option("default", "include_product_stream_excluded_components", False),
+    help="Include product stream excluded components.",
+)
+@click.option(
+    "--output-type-filter",
+    "output_type_filter",
+    type=click.Choice(CorgiService.get_component_types()),
+    default=None,
+    help="Filter component type.",
+)
+@click.option(
+    "-v",
+    "verbose",
+    count=True,
+    default=get_config_option("default", "verbosity", 0),
+    help="Verbose output, more detailed search results, can be used multiple times (e.g. -vvv).",
+)  # noqa
 @click.pass_context
 def get_product_contain_component(
     ctx,
@@ -231,11 +311,21 @@ def get_product_contain_component(
     search_related_url,
     filter_rh_naming,
     search_all,
+    search_all_roots,
+    search_redhat,
     search_community,
     search_upstreams,
+    no_community,
+    no_middleware,
+    include_inactive_product_streams,
+    include_product_stream_excluded_components,
+    output_type_filter,
+    verbose,
 ):
     with console.status("griffoning", spinner="line") as operation_status:
         """List products of a latest component."""
+        if verbose:
+            ctx.obj["VERBOSE"] = verbose
         if not purl and not component_name:
             click.echo(ctx.get_help())
             click.echo("")
@@ -245,15 +335,16 @@ def get_product_contain_component(
         if (
             not search_latest
             and not search_all
+            and not search_all_roots
             and not search_related_url
             and not search_community
             and not search_upstreams
+            and not search_redhat
         ):
             ctx.params["search_latest"] = True
-            ctx.params["search_related_url"] = True
-            # ctx.params["filter_rh_naming"] = True
 
         params = copy.deepcopy(ctx.params)
+        params.pop("verbose")
         params.pop("sfm2_flaw_id")
         params.pop("flaw_mode")
         params.pop("affect_mode")
@@ -264,7 +355,57 @@ def get_product_contain_component(
                 core_queries.products_containing_specific_component_query, params
             )
 
-        # TODO - in the short term affect handling will be mediated via sfm2 here in the operation itself # noqa
+        # TODO: interim hack for middleware
+        if component_name and MIDDLEWARE_CLI and not no_middleware:
+            mw_command = [MIDDLEWARE_CLI, component_name, "-e", "maven", "--json"]
+            if strict_name_search:
+                mw_command.append("-s")
+            proc = subprocess.run(
+                mw_command,
+                capture_output=True,
+                text=True,
+            )
+            mw_json = loads(proc.stdout)
+            mw_components = mw_json["deps"]
+            # TODO: need to determine if we use "build" or "deps"
+            # if search_all:
+            #     mw_components.extend(mw_json["deps"])
+            for build in mw_components:
+                if build["build_type"] == "maven":
+                    component = {
+                        "product_versions": [{"name": build["ps_module"]}],
+                        "product_streams": [
+                            {
+                                "name": build["ps_update_stream"],
+                                "product_versions": [{"name": build["ps_module"]}],
+                            }
+                        ],
+                        "product_active": True,
+                        "type": build["build_type"],
+                        "name": build["build_name"],
+                        "nvr": build["build_nvr"],
+                        "upstreams": [],
+                        "sources": [],
+                        "software_build": {
+                            "build_id": build["build_id"],
+                            "source": build["build_repo"],
+                        },
+                    }
+                    if "sources" in build:
+                        for deps in build["sources"]:
+                            for dep in deps["dependencies"]:
+                                components = []
+                                components.append(
+                                    {
+                                        "name": dep.get("name"),
+                                        "nvr": dep.get("nvr"),
+                                        "type": dep.get("type"),
+                                    }
+                                )
+                                component["sources"] = components
+                    q.append(component)
+
+        # TODO: in the short term affect handling will be mediated via sfm2 here in the operation itself # noqa
         if ctx.params["sfm2_flaw_id"]:
             console.no_color = True
             console.highlighter = None
@@ -272,18 +413,25 @@ def get_product_contain_component(
 
             # generate affects
             output = raw_json_transform(q, True)
-            ordered_results = sorted(output["results"], key=lambda d: d["product_stream"])
-            affects = []
-            product_versions = sorted(
-                list(set([item["product_version"] for item in ordered_results]))
+
+            exclude_products = []
+            if get_config_option(ctx.obj["PROFILE"], "exclude"):
+                exclude_products = get_config_option(ctx.obj["PROFILE"], "exclude").split("\n")
+            exclude_components = []
+            if get_config_option(ctx.obj["PROFILE"], "exclude_components"):
+                exclude_components = get_config_option(
+                    ctx.obj["PROFILE"], "exclude_components"
+                ).split("\n")
+            normalised_results = generate_normalised_results(
+                output,
+                exclude_products,
+                exclude_components,
+                output_type_filter,
+                include_inactive_product_streams,
+                include_product_stream_excluded_components,
             )
-            for pv in product_versions:
-                names = [item["name"] for item in ordered_results if pv == item["product_version"]]
-                names = list(set(names))
-                for name in names:
-                    affects.append(
-                        {"product_version": pv, "component_name": name, "operation": "add"}
-                    )
+            result_tree = generate_result_tree(normalised_results)
+            affects = generate_affects(ctx, result_tree, exclude_components, "add", format="json")
 
             # attempt to import sfm2client module
             try:
@@ -414,6 +562,13 @@ def get_product_contain_component(
     default=False,
     help="Strict search, exact match of component name.",
 )
+@click.option(
+    "-v",
+    "verbose",
+    count=True,
+    default=get_config_option("default", "verbosity", 0),
+    help="Verbose output, more detailed search results, can be used multiple times (e.g. -vvv).",
+)  # noqa
 @click.pass_context
 @progress_bar
 def get_component_contain_component(
@@ -425,8 +580,11 @@ def get_component_contain_component(
     component_arch,
     namespace,
     strict_name_search,
+    verbose,
 ):
     """List components that contain component."""
+    if verbose:
+        ctx.obj["VERBOSE"] = verbose
     if not component_name and not purl:
         click.echo(ctx.get_help())
         exit(0)
@@ -485,9 +643,19 @@ def get_product_manifest_query(ctx, product_stream_name, ofuri, spdx_json_format
         "include_fields": {"type": click.Choice(CorgiService.get_fields(Component))},
     },
 )
+@click.option(
+    "-v",
+    "verbose",
+    count=True,
+    default=get_config_option("default", "verbosity", 0),
+    help="Verbose output, more detailed search results, can be used multiple times (e.g. -vvv).",
+)  # noqa
 @click.pass_context
-def get_product_latest_components_query(ctx, product_stream_name, ofuri, **params):
+def get_product_latest_components_query(ctx, product_stream_name, ofuri, verbose, **params):
     """List components of a specific product version."""
+    if verbose:
+        ctx.obj["VERBOSE"] = verbose
+        ctx.params.pop("verbose")
     if not ofuri and not product_stream_name:
         click.echo(ctx.get_help())
         exit(0)
@@ -496,8 +664,11 @@ def get_product_latest_components_query(ctx, product_stream_name, ofuri, **param
     if product_stream_name:
         # lookup ofuri
         session = CorgiService.create_session()
-        ps = session.product_streams.retrieve_list(name=product_stream_name)
+        ps = session.product_streams.retrieve_list(
+            name=product_stream_name, include_fields="name,ofuri"
+        )
         params["ofuri"] = ps["ofuri"]
+        params["include_fields"] = "name,nvr,related_url,purl,version,release,type,software_build"
     ctx.invoke(list_components, **params)
 
 
